==> lucterios-2.0.3.16020509-py2.py3-none-any.whl: lucterios/framework/static/lucterios.framework/web/js/language.js <==
/*global HashMap*/

var g_translation = new HashMap();

g_translation.put("fr", new HashMap());
g_translation.fr.put("Configuration", "Configuration");
g_translation.fr
		.put(
				"Describ your problem.<br>Thanks<br><br>",
				"Décrivez le plus précisément possible, comment vous avez obtenu ce problème.<br>Merci de votre aide.<br><br>");
g_translation.fr.put("Bug report", "Rapport de bogue");
g_translation.fr.put("Version", "Version");
g_translation.fr.put("Use the <i>Lucterios</i> framework",
		"Utilise le cadre d'application <i>Lucterios</i>");
g_translation.fr.put("Server", "Serveur");
g_translation.fr.put("AJAX client", "Client AJAX");
g_translation.fr.put("Tool of customize management on GPL license",
		"Outil de gestion personnalisé sous licence GPL");
g_translation.fr.put("ask support", "Demande de support");
g_translation.fr.put("About...", "A propos...");
g_translation.fr.put("Logon", "Connexion");
g_translation.fr.put("Logoff", "Déconnexion");
g_translation.fr.put("Refresh", "Rafraichir");
g_translation.fr.put("Error", "Erreur");
g_translation.fr.put("Warning", "Avertissement");
g_translation.fr.put("Information", "Information");
g_translation.fr.put("Call-stack", "Pile d'appel");
g_translation.fr.put("Extra", "Extra");
g_translation.fr.put("Requette", "Requête");
g_translation.fr.put("Reponse", "Réponse");
g_translation.fr.put("Sent to support", "Envoyer au support");
g_translation.fr.put("Page #", "Page N°");
g_translation.fr.put("Select one line before!",
		"Sélectionnez une ligne avant !");
g_translation.fr.put("Select only one line!", "Ne sélectionnez qu'une ligne !");
g_translation.fr.put("Upload impossible<br/>The file must be less than {0}Mo ",
		"Téléchargement impossible<br/>Le fichier doit faire moins de {0}Mo ");
g_translation.fr.put("Loading...", "Chargement...");
g_translation.fr.put("Save as...", "Enregistrer sous...");
g_translation.fr.put("Browser", "Navigateur");
g_translation.fr.put("Connection", "Connexion");
g_translation.fr.put("Ok", "Ok");
g_translation.fr.put("Cancel", "Annuler");
g_translation.fr.put("Login or password wrong!",
		"Alias ou Mot de passe incorrect!");
g_translation.fr.put("Please, identify you", "Veuillez vous identifier");
g_translation.fr.put("Expired session!", "Session expirée !");
g_translation.fr.put("Connection forbideen in this localisation!",
		"Localisation de connexion interdite !");
g_translation.fr.put("Connection", "Connexion");
g_translation.fr.put("Login", "Alias");
g_translation.fr.put("Password", "Mot de passe");
g_translation.fr.put("Close", "Fermer");
g_translation.fr.put("This field is needed!", "Ce champ est obligatoire!");
g_translation.fr.put("The field '{0}' is needed!",
		"Le champ '{0}' est obligatoire!");
g_translation.fr.put("Invalid format!", "Format invalide!");
g_translation.fr.put("Lost connection!", "Connexion perdue!");

g_translation.put("en", new HashMap());
g_translation.en.put("Configuration", "Configuration");
g_translation.en.put("Describ your problem.<br>Thanks<br><br>",
		"Describ your problem.<br>Thanks<br><br>");
g_translation.en.put("Bug report", "Bug report");
g_translation.en.put("Version", "Version");
g_translation.en.put("Use the <i>Lucterios</i> framework",
		"Use the <i>Lucterios</i> framework");
g_translation.en.put("Server", "Server");
g_translation.en.put("AJAX client", "AJAX client");
g_translation.en.put("Tool of customize management on GPL license",
		"Tool of customize management on GPL license");
g_translation.en.put("ask support", "Ask support");
g_translation.en.put("About...", "About...");
g_translation.en.put("Logon", "Logon");
g_translation.en.put("Logoff", "Logoff");
g_translation.en.put("Refresh", "Refresh");
g_translation.en.put("Error", "Error");
g_translation.en.put("Warning", "Warning");
g_translation.en.put("Information", "Information");
g_translation.en.put("Call-stack", "Call-stack");
g_translation.en.put("Extra", "Extra");
g_translation.en.put("Requette", "Request");
g_translation.en.put("Reponse", "Response");
g_translation.en.put("Sent to support", "Sent to support");
g_translation.en.put("Page #", "Page #");
g_translation.en.put("Select one line before!", "Select one line before!");
g_translation.en.put("Select only one line!", "Select only one line!");
g_translation.en.put("Upload impossible<br/>The file must be less than {0}Mo ",
		"Upload impossible<br/>The file must be less than {0}Mo ");
g_translation.en.put("Loading...", "Loading...");
g_translation.en.put("Save as...", "Save as...");
g_translation.en.put("Browser", "Browser");
g_translation.en.put("Connection", "Connection");
g_translation.en.put("Ok", "Ok");
g_translation.en.put("Cancel", "Cancel");
g_translation.en.put("Login or password wrong!", "Wrong login or password !");
g_translation.en.put("Please, identify you", "Please, identify");
g_translation.en.put("Expired session!", "Expired session!");
g_translation.en.put("Connection forbideen in this localisation!",
		"Connection forbiden from this localisation!");
g_translation.en.put("Connection", "Connection");
g_translation.en.put("Login", "Login");
g_translation.en.put("Password", "Password");
g_translation.en.put("Close", "Close");
g_translation.en.put("This field is needed!", "This field is needed!");
g_translation.en
		.put("The field '{0}' is needed!", "The field '{0}' is needed!");
g_translation.en.put("Invalid format!", "Invalid format!");
g_translation.en.put("Lost connection!", "Lost connection!");

==> lucterios-2.0.10.16061815-py2.py3-none-any.whl: lucterios/framework/static/lucterios.framework/web/js/language.js <==
/*global HashMap*/

var g_translation = new HashMap();

g_translation.put("fr", new HashMap());
g_translation.fr.put("Configuration", "Configuration");
g_translation.fr
		.put(
				"Describ your problem.<br>Thanks<br><br>",
				"D&eacute;crivez le plus pr&eacute;cis&eacute;ment possible, comment vous avez obtenu ce probl&egrave;me.<br>Merci de votre aide.<br><br>");
g_translation.fr.put("Bug report", "Rapport de bogue");
g_translation.fr.put("Version", "Version");
g_translation.fr.put("Use the <i>Lucterios</i> framework",
		"Utilise le cadre d'application <i>Lucterios</i>");
g_translation.fr.put("Server", "Serveur");
g_translation.fr.put("AJAX client", "Client AJAX");
g_translation.fr.put("Tool of customize management on GPL license",
		"Outil de gestion personnalis&eacute; sous licence GPL");
g_translation.fr.put("ask support", "Demande de support");
g_translation.fr.put("About...", "A propos...");
g_translation.fr.put("Logon", "Connexion");
g_translation.fr.put("Logoff", "D&eacute;connexion");
g_translation.fr.put("Refresh", "Rafraichir");
g_translation.fr.put("Error", "Erreur");
g_translation.fr.put("Warning", "Avertissement");
g_translation.fr.put("Information", "Information");
g_translation.fr.put("Call-stack", "Pile d'appel");
g_translation.fr.put("Extra", "Extra");
g_translation.fr.put("Requette", "Requ&ecirc;te");
g_translation.fr.put("Reponse", "R&eacute;ponse");
g_translation.fr.put("Sent to support", "Envoyer au support");
g_translation.fr.put("Page #", "Page N°");
g_translation.fr.put("Select one line before!",
		"S&eacute;lectionnez une ligne avant !");
g_translation.fr.put("Select only one line!", "Ne s&eacute;lectionnez qu'une ligne !");
g_translation.fr.put("Upload impossible<br/>The file must be less than {0}Mo ",
		"T&eacute;l&eacute;chargement impossible<br/>Le fichier doit faire moins de {0}Mo ");
g_translation.fr.put("Loading...", "Chargement...");
g_translation.fr.put("Save as...", "Enregistrer sous...");
g_translation.fr.put("Browser", "Navigateur");
g_translation.fr.put("Connection", "Connexion");
g_translation.fr.put("Ok", "Ok");
g_translation.fr.put("Cancel", "Annuler");
g_translation.fr.put("Login or password wrong!",
		"Alias ou Mot de passe incorrect!");
g_translation.fr.put("Please, identify you", "Veuillez vous identifier");
g_translation.fr.put("Expired session!", "Session expir&eacute;e !");
g_translation.fr.put("Connection forbideen in this localisation!",
		"Localisation de connexion interdite !");
g_translation.fr.put("Connection", "Connexion");
g_translation.fr.put("Login", "Alias");
g_translation.fr.put("Password", "Mot de passe");
g_translation.fr.put("Close", "Fermer");
g_translation.fr.put("This field is needed!", "Ce champ est obligatoire!");
g_translation.fr.put("The field '{0}' is needed!",
		"Le champ '{0}' est obligatoire!");
g_translation.fr.put("Invalid format!", "Format invalide!");
g_translation.fr.put("Lost connection!", "Connexion perdue!");

g_translation.put("en", new HashMap());
g_translation.en.put("Configuration", "Configuration");
g_translation.en.put("Describ your problem.<br>Thanks<br><br>",
		"Describ your problem.<br>Thanks<br><br>");
g_translation.en.put("Bug report", "Bug report");
g_translation.en.put("Version", "Version");
g_translation.en.put("Use the <i>Lucterios</i> framework",
		"Use the <i>Lucterios</i> framework");
g_translation.en.put("Server", "Server");
g_translation.en.put("AJAX client", "AJAX client");
g_translation.en.put("Tool of customize management on GPL license",
		"Tool of customize management on GPL license");
g_translation.en.put("ask support", "Ask support");
g_translation.en.put("About...", "About...");
g_translation.en.put("Logon", "Logon");
g_translation.en.put("Logoff", "Logoff");
g_translation.en.put("Refresh", "Refresh");
g_translation.en.put("Error", "Error");
g_translation.en.put("Warning", "Warning");
g_translation.en.put("Information", "Information");
g_translation.en.put("Call-stack", "Call-stack");
g_translation.en.put("Extra", "Extra");
g_translation.en.put("Requette", "Request");
g_translation.en.put("Reponse", "Response");
g_translation.en.put("Sent to support", "Sent to support");
g_translation.en.put("Page #", "Page #");
g_translation.en.put("Select one line before!", "Select one line before!");
g_translation.en.put("Select only one line!", "Select only one line!");
g_translation.en.put("Upload impossible<br/>The file must be less than {0}Mo ",
		"Upload impossible<br/>The file must be less than {0}Mo ");
g_translation.en.put("Loading...", "Loading...");
g_translation.en.put("Save as...", "Save as...");
g_translation.en.put("Browser", "Browser");
g_translation.en.put("Connection", "Connection");
g_translation.en.put("Ok", "Ok");
g_translation.en.put("Cancel", "Cancel");
g_translation.en.put("Login or password wrong!", "Wrong login or password !");
g_translation.en.put("Please, identify you", "Please, identify");
g_translation.en.put("Expired session!", "Expired session!");
g_translation.en.put("Connection forbideen in this localisation!",
		"Connection forbiden from this localisation!");
g_translation.en.put("Connection", "Connection");
g_translation.en.put("Login", "Login");
g_translation.en.put("Password", "Password");
g_translation.en.put("Close", "Close");
g_translation.en.put("This field is needed!", "This field is needed!");
g_translation.en
		.put("The field '{0}' is needed!", "The field '{0}' is needed!");
g_translation.en.put("Invalid format!", "Invalid format!");
g_translation.en.put("Lost connection!", "Lost connection!");
